import * as React from "react";
import { styled } from "@mui/material/styles";
import FormatDate from "./FormatDate";
import IconButton from "@mui/material/IconButton";
import { Link } from "@inertiajs/react";
import userCircle from "@/assets/img/user-circle.svg";
import Lesson from "@/assets/img/lesson.svg";
import Clock from "@/assets/img/clock.svg";
import DeletePopup from "./DeletePopup";
import CopyPopup from "@/Components/CopyPopup";
import { useState } from "react";
import Menu from "@mui/material/Menu";
import MenuItem from "@mui/material/MenuItem";
import MoreVertIcon from "@mui/icons-material/MoreVert";
import Icons from "./Dashboard/Icons";
import Tooltip from "@mui/material/Tooltip";
import { toast } from "react-toastify";

const ExpandMore = styled((props) => {
    const { expand, ...other } = props;
    return <IconButton {...other} />;
})(({ theme, expand }) => ({
    transform: !expand ? "rotate(0deg)" : "rotate(180deg)",
    marginLeft: "auto",
    transition: theme.transitions.create("transform", {
        duration: theme.transitions.duration.shortest,
    }),
}));
const ITEM_HEIGHT = 48;
export default function CourseCard({ course, share_url, image_path }) {
    const [expanded, setExpanded] = React.useState(false);
    const [auth, setAuth] = React.useState(true);
    const [anchorEl, setAnchorEl] = React.useState(null);
    const [showPopup, setShowPopup] = useState(false);
    const [deleteId, setDeleteId] = useState(null);

    const [showCopyPopup, setCopyPopup] = useState(false);
    const [copyId, setCopyId] = useState(null);

    // console.log(course);
    const handleMenu = (event) => {
        setAnchorEl(event.currentTarget);
    };

    const handleClose = () => {
        setAnchorEl(null);
    };

    const handleDelete = (id) => {
        // Handle the delete action here
        console.log("Delete:", id);
    };

    const openDeletePopup = (id) => {
        setShowPopup(true);
        setDeleteId(id);
    };

    const closePopup = () => {
        setShowPopup(false);
    };

    const handleCopy = (id) => {
        const newData = tableData.filter((row) => row.id !== id);
        setTableData(newData);
    };

    const openCopyPopup = (id) => {
        setCopyPopup(true);
        setCopyId(id);
    };

    const closeCopyPopup = () => {
        setCopyPopup(false);
    };

    const open = Boolean(anchorEl);
    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };

    const copyToClipboard = (public_key) => {
        const urlToCopy = share_url + public_key;

        navigator.clipboard
            .writeText(urlToCopy)
            .then(() => {
                toast.success("URL copied to clipboard!");
            })
            .catch((err) => {
                console.error("Failed to copy URL: ", err);
            });
    };

    const truncateText = (text, limit) => {
        return text?.length > limit ? text?.slice(0, limit) + "..." : text;
    };

    return (
        <div className="col-sm-6 col-xl-4 col-xxl-4 mb-4 d-flex">
            <div className="single-course">
                <Link
                    href={`/course/edit-1/${course.id}`}
                    className="course-img-box"
                >
                    <img
                        src="https://asset.uibucket.net/html/iLearning-dashboard/assets/images/course/course-1.jpg"
                        alt="course-img"
                    />
                </Link>
                <div className="course-content-box">
                    <div className="course-content-top">
                        <div className="flex justify-between">
                            <Link
                                href={`/course/edit-1/${course.id}`}
                                className="course-title no-underline break-words"
                            >
                                {course?.title}
                            </Link>
                            <div>
                                <IconButton
                                    aria-label="more"
                                    id="long-button"
                                    aria-controls={
                                        open ? "long-menu" : undefined
                                    }
                                    aria-expanded={open ? "true" : undefined}
                                    aria-haspopup="true"
                                    onClick={handleClick}
                                >
                                    <MoreVertIcon />
                                </IconButton>
                                <Menu
                                    id="long-menu"
                                    MenuListProps={{
                                        "aria-labelledby": "long-button",
                                    }}
                                    anchorEl={anchorEl}
                                    open={open}
                                    onClose={handleClose}
                                    PaperProps={{
                                        style: {
                                            maxHeight: ITEM_HEIGHT * 4.5,
                                            width: "20ch",
                                        },
                                    }}
                                >
                                    <MenuItem onClick={handleClose}>
                                        <span
                                            onClick={() =>
                                                openDeletePopup(course.id)
                                            }
                                        >
                                            Delete
                                        </span>
                                    </MenuItem>
                                    <MenuItem onClick={handleClose}>
                                        <span
                                            onClick={() =>
                                                openCopyPopup(course.id)
                                            }
                                        >
                                            Copy
                                        </span>
                                    </MenuItem>
                                    <MenuItem onClick={handleClose}>
                                        <span
                                            onClick={() =>
                                                copyToClipboard(
                                                    course.public_key
                                                )
                                            }
                                        >
                                            Copy Url
                                        </span>
                                    </MenuItem>
                                </Menu>
                                <DeletePopup
                                    show={showPopup}
                                    // width="w-full"
                                    message="Are you sure you want to delete this event?"
                                    onClose={closePopup}
                                    confirmLink={`/course/delete-course/${deleteId}`}
                                />

                                <CopyPopup
                                    show={showCopyPopup}
                                    message="Are you sure you want to copy this course?"
                                    onClose={closeCopyPopup}
                                    confirmLink={`/course/copy-course/${copyId}`}
                                />
                            </div>
                        </div>
                        <div className="course-short-desc">
                            <p>
                                <span>
                                    <img src={userCircle} alt="user" />
                                </span>
                                Enroll {course.number_of_enrollment}
                            </p>
                            <p>
                                <span>
                                    <img src={Lesson} alt="lesson" />
                                </span>
                                {course.videos.length} Lesson
                            </p>
                            <p>
                                <span>
                                    <img src={Clock} alt="clock" />
                                </span>
                                <FormatDate dateString={course.created_at} />
                            </p>
                        </div>
                    </div>
                    <div className="divider" />
                    <div className="course-content-bottom max-sm:gap-3">
                        <Link
                            href={`/view-course/${course.public_key}`}
                            target="_blank"
                            className="btn btn-purple"
                        >
                            <Icons
                                name="tabler:eye"
                                className="text-white w-5 h-5"
                            />
                            View Course
                        </Link>
                        {course.course_type == "paid" && course.course_price ? (
                            <h4 className="course-price">
                                &#x20b9; {course.course_price}{" "}
                            </h4>
                        ) : (
                            <h4 className="course-price">Free</h4>
                        )}
                    </div>
                </div>
            </div>
        </div>
    );
}
